@@ -136,9 +136,9 @@ class DBProxy:
         return await self.raw_sql(query, execute=execute)
 
     async def _get_all_entities_name(self):
-        # TODO: refactor using sdk.client and fetch_all
+        # TODO: refactor using StructureDefintion
         query_url = f"{self._settings.APP_INIT_URL}/Entity?type=resource&_elements=id&_count=999"
-        async with self._client.get(query_url, raise_for_status=True) as resp:
+        async with self._client.get(query_url) as resp:
             json_resp = await resp.json()
             return [entry["resource"]["id"] for entry in json_resp.get("entry", [])]
 
